@@ -211,11 +211,11 @@ struct nvidia_softc {
     void *irq_ih;
     int   irq_rid;
 
-    nv_stack_t *attach_sp;
-    nv_stack_t *api_sp;
-    nv_stack_t *pci_cfgchk_sp;
-    nv_stack_t *isr_sp;
-    nv_stack_t *timer_sp;
+    nvidia_stack_t *attach_sp;
+    nvidia_stack_t *api_sp;
+    nvidia_stack_t *pci_cfgchk_sp;
+    nvidia_stack_t *isr_sp;
+    nvidia_stack_t *timer_sp;
 
     struct resource *iop;
     int iop_rid;
@@ -313,9 +313,9 @@ int    nvidia_ctl_attach     (void);
 int    nvidia_ctl_detach     (void);
 
 /* nvidia_pci.c */
-void   nvidia_pci_save_config_space   (nv_stack_t *, device_t dev);
-void   nvidia_pci_restore_config_space(nv_stack_t *, device_t dev);
-void   nvidia_pci_check_config_space  (nv_stack_t *, device_t dev, BOOL, BOOL, BOOL);
+void   nvidia_pci_save_config_space   (nvidia_stack_t *, device_t dev);
+void   nvidia_pci_restore_config_space(nvidia_stack_t *, device_t dev);
+void   nvidia_pci_check_config_space  (nvidia_stack_t *, device_t dev, BOOL, BOOL, BOOL);
 int    nvidia_pci_setup_intr          (device_t dev);
 int    nvidia_pci_teardown_intr       (device_t dev);
 NvU8   nvidia_pci_find_capability     (device_t dev, NvU8);
