@@ -278,23 +278,6 @@
 #define __NV_RM_MSG RmMsg
 #define NV_RM_MSG NV_REG_STRING(__NV_RM_MSG)
 
-/*
- * Option: RMEdgeIntrCheck
- *
- * Description:
- *
- * Enable/disable check for edge-triggered interrupts.
- * Please see the common problems section of the readme for more
- * details on edge-triggered interrupt problems.
- *
- * Possible values:
- * 1 - enable edge-triggered interrupt check (default)
- * 0 - disable edge-triggered interrupt check
- */
-
-#define __NV_RM_EDGE_INTR_CHECK  RMEdgeIntrCheck
-#define NV_REG_RM_EDGE_INTR_CHECK NV_REG_STRING(__NV_RM_EDGE_INTR_CHECK)
-
 /*
  * Option: UsePageAttributeTable
  *
@@ -478,7 +461,6 @@ NV_DEFINE_REG_ENTRY(__NV_DEVICE_FILE_MODE, 0666);
 NV_DEFINE_REG_ENTRY(__NV_REMAP_LIMIT, 0);
 NV_DEFINE_REG_ENTRY(__NV_UPDATE_MEMORY_TYPES, ~0);
 NV_DEFINE_REG_ENTRY(__NV_INITIALIZE_SYSTEM_MEMORY_ALLOCATIONS, 1);
-NV_DEFINE_REG_ENTRY(__NV_RM_EDGE_INTR_CHECK, 1);
 NV_DEFINE_REG_ENTRY(__NV_USE_PAGE_ATTRIBUTE_TABLE, ~0);
 NV_DEFINE_REG_ENTRY(__NV_MAP_REGISTERS_EARLY, 0);
 NV_DEFINE_REG_ENTRY(__NV_REGISTER_FOR_ACPI_EVENTS, 1);
@@ -487,10 +469,8 @@ NV_DEFINE_REG_ENTRY(__NV_ENABLE_PCIE_GEN3, 0);
 NV_DEFINE_REG_ENTRY(__NV_ENABLE_MSI, 1);
 NV_DEFINE_REG_ENTRY_GLOBAL(__NV_MEMORY_POOL_SIZE, 0);
 
-#if defined(NV_LINUX) || defined(NV_VMWARE)
 NV_DEFINE_REG_STRING_ENTRY(__NV_REGISTRY_DWORDS, NULL);
 NV_DEFINE_REG_STRING_ENTRY(__NV_RM_MSG, NULL);
-#endif
 
 #if !defined(NV_VMWARE)
 NV_DEFINE_REG_STRING_ENTRY(__NV_ASSIGN_GPUS, NULL);
@@ -518,7 +498,6 @@ nv_parm_t nv_parms[] = {
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_REMAP_LIMIT),
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_UPDATE_MEMORY_TYPES),
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_INITIALIZE_SYSTEM_MEMORY_ALLOCATIONS),
-    NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_RM_EDGE_INTR_CHECK),
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_USE_PAGE_ATTRIBUTE_TABLE),
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_ENABLE_MSI),
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_MAP_REGISTERS_EARLY),
