@@ -49,14 +49,6 @@ typedef struct {
 #define NV_ESC_CHECK_VERSION_STR (NV_IOCTL_BASE + 10)
 #define NV_ESC_IOCTL_XFER_CMD    (NV_IOCTL_BASE + 11)
 
-#if defined(NV_SUNOS)
-#define NV_PLATFORM_MAX_IOCTL_SIZE  255
-#elif (defined(NV_LINUX) || defined(NV_BSD) || defined(NV_VMWARE))
-#define NV_PLATFORM_MAX_IOCTL_SIZE  4096
-#else
-#error "The maximum ioctl() argument size is undefined!"
-#endif
-
 /*
  * #define an absolute maximum used as a sanity check for the
  * NV_ESC_IOCTL_XFER_CMD ioctl() size argument.
@@ -99,6 +91,7 @@ typedef struct nv_ioctl_card_info
     NvU64         fb_address     NV_ALIGN_BYTES(8);
     NvU64         fb_size        NV_ALIGN_BYTES(8);
     NvU32         minor_number;
+    NvU8          dev_name[10];  /* device names such as vmgfx[0-32] for vmkernel */
 } nv_ioctl_card_info_t;
 
 #define NV_IOCTL_CARD_INFO_BUS_TYPE_PCI            0x0001
@@ -143,26 +136,26 @@ typedef struct nv_ioctl_rm_api_old_version
 
 typedef enum {
     NV_CPU_TYPE_UNKNOWN = 0,
-    NV_CPU_TYPE_ARM_A15
+    NV_CPU_TYPE_ARM_A9
 } nv_cpu_type_t;
 
 /* alloc event */
 typedef struct nv_ioctl_alloc_os_event
 {
-    NvU32 hClient;
-    NvU32 hDevice;
-    NvU32 hOsEvent;
-    NvU32 fd;
-    NvU32 Status;
+    NvHandle hClient;
+    NvHandle hDevice;
+    NvHandle hOsEvent;
+    NvU32    fd;
+    NvU32    Status;
 } nv_ioctl_alloc_os_event_t;
 
 /* free event */
 typedef struct nv_ioctl_free_os_event
 {
-    NvU32 hClient;
-    NvU32 hDevice;
-    NvU32 fd;
-    NvU32 Status;
+    NvHandle hClient;
+    NvHandle hDevice;
+    NvU32    fd;
+    NvU32    Status;
 } nv_ioctl_free_os_event_t;
 
 #define NV_CTL_DEVICE_PCI_DOMAIN        0
@@ -173,6 +166,10 @@ typedef struct nv_ioctl_free_os_event
     (((domain) == NV_CTL_DEVICE_PCI_DOMAIN) && \
      ((bus) == NV_CTL_DEVICE_PCI_BUS) && ((slot) == NV_CTL_DEVICE_PCI_SLOT))
 
+#define NV_PCI_DEV_FMT          "%04x:%02x:%02x.%x"
+#define NV_PCI_DEV_FMT_ARGS(nv) (nv)->pci_info.domain, (nv)->pci_info.bus, \
+                                (nv)->pci_info.slot, (nv)->pci_info.function
+
 /* status code */
 typedef struct nv_ioctl_status_code
 {
@@ -223,7 +220,7 @@ typedef union
 #define NVRM_PCICFG_BAR_MEMTYPE_64BIT   0x00000004
 #define NVRM_PCICFG_BAR_ADDR_MASK       0xfffffff0
 
-#define NVRM_PCICFG_NUM_DWORDS          64
+#define NVRM_PCICFG_NUM_DWORDS          16
 
 #define NV_GPU_NUM_BARS                 3
 #define NV_GPU_BAR_INDEX_REGS           0
@@ -264,12 +261,17 @@ typedef struct
 #define NV_STACK_SIZE (NV_RM_PAGE_SIZE * 2)
 #endif
 
-typedef struct nv_stack_s
+typedef struct nvidia_stack_s
 {
     NvU32 size;
     void *top;
     NvU8  stack[NV_STACK_SIZE-16] __attribute__ ((aligned(16)));
-} nv_stack_t;
+} nvidia_stack_t;
+
+/*
+ * TODO: Remove once all UNIX layers have been converted to use nvidia_stack_t
+ */
+typedef nvidia_stack_t nv_stack_t;
 
 /*
  * this is a wrapper for unix events
@@ -278,13 +280,13 @@ typedef struct nv_stack_s
  */
 typedef struct nv_event_s
 {
-    NvU32 hParent;
-    NvU32 hObject;
-    NvU32 index;
-    void  *file;  /* per file-descriptor data pointer */
-    NvU32 handle;
-    NvU32 fd;
-    struct nv_event_s *next;
+    NvHandle            hParent;
+    NvHandle            hObject;
+    NvU32               index;
+    void               *file;  /* per file-descriptor data pointer */
+    NvHandle            handle;
+    NvU32               fd;
+    struct nv_event_s  *next;
 } nv_event_t;
 
 typedef struct nv_kern_mapping_s
@@ -332,7 +334,7 @@ typedef struct
 
     NvU32  interrupt_line;
 
-    NvU32 primary_vga;
+    NvBool primary_vga;
 
     NvU32 sim_env;
 
@@ -356,7 +358,8 @@ typedef struct gpuAddressSpace *nvgpuAddressSpaceHandle_t;
 typedef struct gpuChannel      *nvgpuChannelHandle_t;
 typedef struct gpuObject       *nvgpuObjectHandle_t;
 typedef struct gpuChannelInfo  *nvgpuChannelInfo_t;
-typedef struct gpuCaps *nvgpuCaps_t;
+typedef struct gpuCaps         *nvgpuCaps_t;
+typedef struct gpuAllocInfo    *nvgpuAllocInfo_t;
 
 typedef struct
 {
@@ -560,10 +563,10 @@ typedef struct
 
 
 void*      NV_API_CALL  nv_alloc_kernel_mapping  (nv_state_t *, void *, NvU64, NvU32, NvU64, void **);
-RM_STATUS  NV_API_CALL  nv_free_kernel_mapping   (nv_state_t *, void *, void *, void *);
-RM_STATUS  NV_API_CALL  nv_alloc_user_mapping    (nv_state_t *, void *, NvU64, NvU32, NvU64, NvU32, NvU64 *, void **);
-RM_STATUS  NV_API_CALL  nv_free_user_mapping     (nv_state_t *, void *, NvU64, void *);
-RM_STATUS  NV_API_CALL  nv_create_user_mapping_context (nv_state_t *, NvU64, NvU64, void **);
+NV_STATUS  NV_API_CALL  nv_free_kernel_mapping   (nv_state_t *, void *, void *, void *);
+NV_STATUS  NV_API_CALL  nv_alloc_user_mapping    (nv_state_t *, void *, NvU64, NvU32, NvU64, NvU32, NvU64 *, void **);
+NV_STATUS  NV_API_CALL  nv_free_user_mapping     (nv_state_t *, void *, NvU64, void *);
+NV_STATUS  NV_API_CALL  nv_create_user_mapping_context (nv_state_t *, NvU64, NvU64, void **);
 
 NvU64  NV_API_CALL  nv_get_kern_phys_address     (NvU64);
 NvU64  NV_API_CALL  nv_get_user_phys_address     (NvU64);
@@ -571,17 +574,17 @@ void*  NV_API_CALL  nv_get_adapter_state         (NvU32, NvU8, NvU8);
 
 void   NV_API_CALL  nv_set_dma_address_size      (nv_state_t *, NvU32 );
 
-RM_STATUS  NV_API_CALL  nv_alias_pages           (nv_state_t *, NvU32, NvU32, NvU32, NvU64, NvU64 *, void **);
-RM_STATUS  NV_API_CALL  nv_alloc_pages           (nv_state_t *, NvU32, NvBool, NvU32, NvBool, NvU64 *, void **);
-RM_STATUS  NV_API_CALL  nv_free_pages            (nv_state_t *, NvU32, NvBool, NvU32, void *);
+NV_STATUS  NV_API_CALL  nv_alias_pages           (nv_state_t *, NvU32, NvU32, NvU32, NvU64, NvU64 *, void **);
+NV_STATUS  NV_API_CALL  nv_alloc_pages           (nv_state_t *, NvU32, NvBool, NvU32, NvBool, NvU64 *, void **);
+NV_STATUS  NV_API_CALL  nv_free_pages            (nv_state_t *, NvU32, NvBool, NvU32, void *);
 
-RM_STATUS  NV_API_CALL  nv_dma_map_pages         (nv_state_t *, NvU64, NvU64 *, void **);
-RM_STATUS  NV_API_CALL  nv_dma_unmap_pages       (nv_state_t *, NvU64, NvU64 *, void **);
+NV_STATUS  NV_API_CALL  nv_dma_map_pages         (nv_state_t *, NvU64, NvU64 *, void **);
+NV_STATUS  NV_API_CALL  nv_dma_unmap_pages       (nv_state_t *, NvU64, NvU64 *, void **);
 
 NvS32  NV_API_CALL  nv_start_rc_timer            (nv_state_t *);
 NvS32  NV_API_CALL  nv_stop_rc_timer             (nv_state_t *);
 
-void   NV_API_CALL  nv_post_event                (nv_state_t *, nv_event_t *, NvU32, NvU32, NvBool);
+void   NV_API_CALL  nv_post_event                (nv_state_t *, nv_event_t *, NvHandle, NvU32, NvBool);
 NvS32  NV_API_CALL  nv_get_event                 (nv_state_t *, void *, nv_event_t *, NvU32 *);
 
 NvS32  NV_API_CALL  nv_no_incoherent_mappings    (void);
@@ -594,25 +597,27 @@ BOOL   NV_API_CALL  nv_i2c_del_adapter           (nv_state_t *, void *);
 void   NV_API_CALL  nv_acpi_methods_init         (NvU32 *);
 void   NV_API_CALL  nv_acpi_methods_uninit       (void);
 
-RM_STATUS  NV_API_CALL  nv_acpi_method           (NvU32, NvU32, NvU32, void *, NvU16, NvU32 *, void *, NvU16 *);
-RM_STATUS  NV_API_CALL  nv_acpi_dsm_method       (nv_state_t *, NvU8 *, NvU32, NvU32, void *, NvU16, NvU32 *, void *, NvU16 *);
-RM_STATUS  NV_API_CALL  nv_acpi_ddc_method       (nv_state_t *, void *, NvU32 *);
-RM_STATUS  NV_API_CALL  nv_acpi_dod_method       (nv_state_t *, NvU32 *, NvU32 *);
+NV_STATUS  NV_API_CALL  nv_acpi_method           (NvU32, NvU32, NvU32, void *, NvU16, NvU32 *, void *, NvU16 *);
+NV_STATUS  NV_API_CALL  nv_acpi_dsm_method       (nv_state_t *, NvU8 *, NvU32, NvU32, void *, NvU16, NvU32 *, void *, NvU16 *);
+NV_STATUS  NV_API_CALL  nv_acpi_ddc_method       (nv_state_t *, void *, NvU32 *);
+NV_STATUS  NV_API_CALL  nv_acpi_dod_method       (nv_state_t *, NvU32 *, NvU32 *);
 void*      NV_API_CALL  nv_get_smu_state         (void);
-RM_STATUS  NV_API_CALL  nv_acpi_rom_method       (nv_state_t *, NvU32 *, NvU32 *);
-RM_STATUS  NV_API_CALL  nv_log_error             (nv_state_t *, NvU32, const char *, va_list);
+NV_STATUS  NV_API_CALL  nv_acpi_rom_method       (nv_state_t *, NvU32 *, NvU32 *);
+NV_STATUS  NV_API_CALL  nv_log_error             (nv_state_t *, NvU32, const char *, va_list);
 
 #if defined(NV_MOBILE_DGPU)
-RM_STATUS  NV_API_CALL  nv_nvmap_create_client   (void);
+NV_STATUS  NV_API_CALL  nv_nvmap_create_client   (void);
 void       NV_API_CALL  nv_nvmap_destroy_client  (void);
 void       NV_API_CALL  nv_nvmap_free_handle_id  (NvU32);
-RM_STATUS  NV_API_CALL  nv_nvmap_dup_handle_id   (NvU32 *, NvU32);
-RM_STATUS  NV_API_CALL  nv_nvmap_get_page_list_info (NvU32, NvU32 *, NvU32 *, NvU32 *, BOOL *, NvU32 *);
-RM_STATUS  NV_API_CALL  nv_nvmap_get_page_list   (nv_state_t *, void *, NvU64, NvU64 *, void **, NvU32);
-RM_STATUS  NV_API_CALL  nv_nvmap_release_pages   (nv_state_t *, NvU64, NvU64 *, void *, NvU32);
+NV_STATUS  NV_API_CALL  nv_nvmap_dup_handle_id   (NvU32 *, NvU32);
+NV_STATUS  NV_API_CALL  nv_nvmap_get_page_list_info (NvU32, NvU32 *, NvU32 *, NvU32 *, BOOL *, NvU32 *);
+NV_STATUS  NV_API_CALL  nv_nvmap_get_page_list   (nv_state_t *, void *, NvU64, NvU64 *, void **, NvU32);
+NV_STATUS  NV_API_CALL  nv_nvmap_release_pages   (nv_state_t *, NvU64, NvU64 *, void *, NvU32);
 #endif
-RM_STATUS  NV_API_CALL  nv_alloc_os_descriptor_handle (nv_state_t *, NvS32, void *, NvU64, NvU32 *);
+NV_STATUS  NV_API_CALL  nv_alloc_os_descriptor_handle (nv_state_t *, NvS32, void *, NvU64, NvU32 *);
 NvU64      NV_API_CALL  nv_get_dma_start_address (nv_state_t *);
+NV_STATUS  NV_API_CALL  nv_set_primary_vga_status(nv_state_t *);
+NV_STATUS  NV_API_CALL  nv_pci_trigger_recovery  (nv_state_t *);
 
 #if defined(NVCPU_X86) || defined(NVCPU_X86_64)
 NvBool     NV_API_CALL  nv_is_virtualized_system  (nv_stack_t *);
@@ -626,91 +631,93 @@ NvBool     NV_API_CALL  nv_is_virtualized_system  (nv_stack_t *);
  * ---------------------------------------------------------------------------
  */
 
-BOOL       NV_API_CALL  rm_init_rm               (nv_stack_t *);
-BOOL       NV_API_CALL  rm_shutdown_rm           (nv_stack_t *);
-BOOL       NV_API_CALL  rm_init_private_state    (nv_stack_t *, nv_state_t *);
-BOOL       NV_API_CALL  rm_free_private_state    (nv_stack_t *, nv_state_t *);
-BOOL       NV_API_CALL  rm_init_adapter          (nv_stack_t *, nv_state_t *);
-BOOL       NV_API_CALL  rm_disable_adapter       (nv_stack_t *, nv_state_t *);
-BOOL       NV_API_CALL  rm_shutdown_adapter      (nv_stack_t *, nv_state_t *);
-RM_STATUS  NV_API_CALL  rm_extract_mmap_context  (nv_stack_t *, nv_state_t *, NvP64, NvU64, void **);
-void       NV_API_CALL  rm_purge_mmap_contexts   (nv_stack_t *, nv_state_t *, void *);
-RM_STATUS  NV_API_CALL  rm_validate_mmap_request (nv_stack_t *, nv_state_t *, void *, NvU64, NvU64, NvU32 *, void **, NvU64 *);
-RM_STATUS  NV_API_CALL  rm_acquire_api_lock      (nv_stack_t *);
-RM_STATUS  NV_API_CALL  rm_release_api_lock      (nv_stack_t *);
-RM_STATUS  NV_API_CALL  rm_ioctl                 (nv_stack_t *, nv_state_t *, void *, NvU32, void *, NvU32);
-BOOL       NV_API_CALL  rm_isr                   (nv_stack_t *, nv_state_t *, NvU32 *);
-void       NV_API_CALL  rm_isr_bh                (nv_stack_t *, nv_state_t *);
-RM_STATUS  NV_API_CALL  rm_power_management      (nv_stack_t *, nv_state_t *, NvU32, NvU32);
-RM_STATUS  NV_API_CALL  rm_save_low_res_mode     (nv_stack_t *, nv_state_t *);
-RM_STATUS  NV_API_CALL  rm_get_vbios_version     (nv_stack_t *, nv_state_t *, NvU32 *, NvU32 *, NvU32 *, NvU32 *, NvU32 *);
-RM_STATUS  NV_API_CALL  rm_get_gpu_uuid          (nv_stack_t *, nv_state_t *, NvU8 **, NvU32 *);
-RM_STATUS  NV_API_CALL  rm_get_gpu_uuid_raw      (nv_stack_t *, nv_state_t *, NvU8 **, NvU32 *);
-void       NV_API_CALL  rm_free_unused_clients   (nv_stack_t *, nv_state_t *, void *);
-void       NV_API_CALL  rm_unbind_lock           (nv_stack_t *, nv_state_t *);
+BOOL       NV_API_CALL  rm_init_rm               (nvidia_stack_t *);
+BOOL       NV_API_CALL  rm_shutdown_rm           (nvidia_stack_t *);
+BOOL       NV_API_CALL  rm_init_private_state    (nvidia_stack_t *, nv_state_t *);
+BOOL       NV_API_CALL  rm_free_private_state    (nvidia_stack_t *, nv_state_t *);
+BOOL       NV_API_CALL  rm_init_adapter          (nvidia_stack_t *, nv_state_t *);
+BOOL       NV_API_CALL  rm_disable_adapter       (nvidia_stack_t *, nv_state_t *);
+BOOL       NV_API_CALL  rm_shutdown_adapter      (nvidia_stack_t *, nv_state_t *);
+NV_STATUS  NV_API_CALL  rm_extract_mmap_context  (nvidia_stack_t *, nv_state_t *, NvP64, NvU64, void **);
+void       NV_API_CALL  rm_purge_mmap_contexts   (nvidia_stack_t *, nv_state_t *, void *);
+NV_STATUS  NV_API_CALL  rm_validate_mmap_request (nvidia_stack_t *, nv_state_t *, void *, NvU64, NvU64, NvU32 *, void **, NvU64 *);
+NV_STATUS  NV_API_CALL  rm_acquire_api_lock      (nvidia_stack_t *);
+NV_STATUS  NV_API_CALL  rm_release_api_lock      (nvidia_stack_t *);
+NV_STATUS  NV_API_CALL  rm_ioctl                 (nvidia_stack_t *, nv_state_t *, void *, NvU32, void *, NvU32);
+BOOL       NV_API_CALL  rm_isr                   (nvidia_stack_t *, nv_state_t *, NvU32 *);
+void       NV_API_CALL  rm_isr_bh                (nvidia_stack_t *, nv_state_t *);
+NV_STATUS  NV_API_CALL  rm_power_management      (nvidia_stack_t *, nv_state_t *, NvU32, NvU32);
+NV_STATUS  NV_API_CALL  rm_save_low_res_mode     (nvidia_stack_t *, nv_state_t *);
+NV_STATUS  NV_API_CALL  rm_get_vbios_version     (nvidia_stack_t *, nv_state_t *, NvU32 *, NvU32 *, NvU32 *, NvU32 *, NvU32 *);
+NV_STATUS  NV_API_CALL  rm_get_gpu_uuid          (nvidia_stack_t *, nv_state_t *, NvU8 **, NvU32 *);
+NV_STATUS  NV_API_CALL  rm_get_gpu_uuid_raw      (nvidia_stack_t *, nv_state_t *, NvU8 **, NvU32 *);
+void       NV_API_CALL  rm_free_unused_clients   (nvidia_stack_t *, nv_state_t *, void *);
+void       NV_API_CALL  rm_unbind_lock           (nvidia_stack_t *, nv_state_t *);
 
-RM_STATUS  NV_API_CALL  rm_read_registry_dword   (nv_stack_t *, nv_state_t *, NvU8 *, NvU8 *, NvU32 *);
-RM_STATUS  NV_API_CALL  rm_write_registry_dword  (nv_stack_t *, nv_state_t *, NvU8 *, NvU8 *, NvU32);
-RM_STATUS  NV_API_CALL  rm_read_registry_binary  (nv_stack_t *, nv_state_t *, NvU8 *, NvU8 *, NvU8 *, NvU32 *);
-RM_STATUS  NV_API_CALL  rm_write_registry_binary (nv_stack_t *, nv_state_t *, NvU8 *, NvU8 *, NvU8 *, NvU32);
-RM_STATUS  NV_API_CALL  rm_write_registry_string (nv_stack_t *, nv_state_t *, NvU8 *, NvU8 *, const char *, NvU32);
+NV_STATUS  NV_API_CALL  rm_read_registry_dword   (nvidia_stack_t *, nv_state_t *, NvU8 *, NvU8 *, NvU32 *);
+NV_STATUS  NV_API_CALL  rm_write_registry_dword  (nvidia_stack_t *, nv_state_t *, NvU8 *, NvU8 *, NvU32);
+NV_STATUS  NV_API_CALL  rm_read_registry_binary  (nvidia_stack_t *, nv_state_t *, NvU8 *, NvU8 *, NvU8 *, NvU32 *);
+NV_STATUS  NV_API_CALL  rm_write_registry_binary (nvidia_stack_t *, nv_state_t *, NvU8 *, NvU8 *, NvU8 *, NvU32);
+NV_STATUS  NV_API_CALL  rm_write_registry_string (nvidia_stack_t *, nv_state_t *, NvU8 *, NvU8 *, const char *, NvU32);
 
-RM_STATUS  NV_API_CALL  rm_run_rc_callback       (nv_stack_t *, nv_state_t *);
-void       NV_API_CALL  rm_execute_work_item     (nv_stack_t *, void *);
-RM_STATUS  NV_API_CALL  rm_get_device_name       (nv_stack_t *, nv_state_t *, NvU16, NvU16, NvU16, NvU32, NvU8 *);
+NV_STATUS  NV_API_CALL  rm_run_rc_callback       (nvidia_stack_t *, nv_state_t *);
+void       NV_API_CALL  rm_execute_work_item     (nvidia_stack_t *, void *);
+NV_STATUS  NV_API_CALL  rm_get_device_name       (nvidia_stack_t *, nv_state_t *, NvU16, NvU16, NvU16, NvU32, NvU8 *);
 
 NvU64      NV_API_CALL  nv_rdtsc                 (void);
 
-void       NV_API_CALL  rm_register_compatible_ioctls   (nv_stack_t *);
-void       NV_API_CALL  rm_unregister_compatible_ioctls (nv_stack_t *);
+void       NV_API_CALL  rm_register_compatible_ioctls   (nvidia_stack_t *);
+void       NV_API_CALL  rm_unregister_compatible_ioctls (nvidia_stack_t *);
 
-BOOL       NV_API_CALL  rm_is_legacy_device      (nv_stack_t *, NvU16, NvU16, NvU16, BOOL);
+BOOL       NV_API_CALL  rm_is_legacy_device      (nvidia_stack_t *, NvU16, NvU16, NvU16, BOOL);
 BOOL       NV_API_CALL  rm_is_legacy_arch        (NvU32, NvU32);
-RM_STATUS  NV_API_CALL  rm_is_supported_device   (nv_stack_t *, nv_state_t *, NvU32 *, NvU32 *);
+NV_STATUS  NV_API_CALL  rm_is_supported_device   (nvidia_stack_t *, nv_state_t *, NvU32 *, NvU32 *);
 
 
-void       NV_API_CALL  rm_check_pci_config_space (nv_stack_t *, nv_state_t *nv, BOOL, BOOL, BOOL);
+void       NV_API_CALL  rm_check_pci_config_space (nvidia_stack_t *, nv_state_t *nv, BOOL, BOOL, BOOL);
 
-RM_STATUS  NV_API_CALL  rm_i2c_remove_adapters    (nv_stack_t *, nv_state_t *);
-NvBool     NV_API_CALL  rm_i2c_is_smbus_capable   (nv_stack_t *, nv_state_t *, void *);
-RM_STATUS  NV_API_CALL  rm_i2c_transfer           (nv_stack_t *, nv_state_t *, void *, NvU8, NvU8, NvU8, NvU32, NvU8 *);
+NV_STATUS  NV_API_CALL  rm_i2c_remove_adapters    (nvidia_stack_t *, nv_state_t *);
+NvBool     NV_API_CALL  rm_i2c_is_smbus_capable   (nvidia_stack_t *, nv_state_t *, void *);
+NV_STATUS  NV_API_CALL  rm_i2c_transfer           (nvidia_stack_t *, nv_state_t *, void *, NvU8, NvU8, NvU8, NvU32, NvU8 *);
 
-RM_STATUS  NV_API_CALL  rm_perform_version_check  (nv_stack_t *, void *, NvU32);
+NV_STATUS  NV_API_CALL  rm_perform_version_check  (nvidia_stack_t *, void *, NvU32);
 
-RM_STATUS  NV_API_CALL  rm_system_event           (nv_stack_t *, NvU32, NvU32);
-RM_STATUS  NV_API_CALL  rm_init_smu               (nv_stack_t *, nv_smu_state_t *);
-RM_STATUS  NV_API_CALL  rm_shutdown_smu           (nv_stack_t *, nv_smu_state_t *);
-RM_STATUS  NV_API_CALL  rm_suspend_smu            (nv_stack_t *);
-RM_STATUS  NV_API_CALL  rm_resume_smu             (nv_stack_t *);
+NV_STATUS  NV_API_CALL  rm_system_event           (nvidia_stack_t *, NvU32, NvU32);
+NV_STATUS  NV_API_CALL  rm_init_smu               (nvidia_stack_t *, nv_smu_state_t *);
+NV_STATUS  NV_API_CALL  rm_shutdown_smu           (nvidia_stack_t *, nv_smu_state_t *);
+NV_STATUS  NV_API_CALL  rm_suspend_smu            (nvidia_stack_t *);
+NV_STATUS  NV_API_CALL  rm_resume_smu             (nvidia_stack_t *);
 
-void       NV_API_CALL  rm_disable_gpu_state_persistence    (nv_stack_t *sp, nv_state_t *);
-RM_STATUS  NV_API_CALL  rm_p2p_init_mapping       (nv_stack_t *, NvU64, NvU64 *, NvU64 *, NvU64 *, NvU64 *, NvU64, NvU64, NvU64, NvU64, void (*)(void *), void *);
-RM_STATUS  NV_API_CALL  rm_p2p_destroy_mapping    (nv_stack_t *, NvU64);
-RM_STATUS  NV_API_CALL  rm_p2p_get_pages          (nv_stack_t *, NvU64, NvU32, NvU64, NvU64, NvU64 **, NvU32 **, NvU32 **, NvU32 *, void *, void (*)(void *), void *);
-RM_STATUS  NV_API_CALL  rm_p2p_put_pages          (nv_stack_t *, NvU64, NvU32, NvU64, void *);
-RM_STATUS  NV_API_CALL  rm_get_cpu_type           (nv_stack_t *, nv_cpu_type_t *);
+void       NV_API_CALL  rm_disable_gpu_state_persistence    (nvidia_stack_t *sp, nv_state_t *);
+NV_STATUS  NV_API_CALL  rm_p2p_init_mapping       (nvidia_stack_t *, NvU64, NvU64 *, NvU64 *, NvU64 *, NvU64 *, NvU64, NvU64, NvU64, NvU64, void (*)(void *), void *);
+NV_STATUS  NV_API_CALL  rm_p2p_destroy_mapping    (nvidia_stack_t *, NvU64);
+NV_STATUS  NV_API_CALL  rm_p2p_get_pages          (nvidia_stack_t *, NvU64, NvU32, NvU64, NvU64, NvU64 **, NvU32 **, NvU32 **, NvU32 *, void *, void (*)(void *), void *);
+NV_STATUS  NV_API_CALL  rm_p2p_put_pages          (nvidia_stack_t *, NvU64, NvU32, NvU64, void *);
+NV_STATUS  NV_API_CALL  rm_get_cpu_type           (nvidia_stack_t *, nv_cpu_type_t *);
+NV_STATUS  NV_API_CALL  rm_log_gpu_crash          (nv_stack_t *, nv_state_t *);
 
-RM_STATUS  NV_API_CALL  rm_gpu_ops_create_session (nv_stack_t *, nvgpuSessionHandle_t *);
-RM_STATUS  NV_API_CALL  rm_gpu_ops_destroy_session (nv_stack_t *, nvgpuSessionHandle_t);
-RM_STATUS  NV_API_CALL  rm_gpu_ops_address_space_create(nv_stack_t *, nvgpuSessionHandle_t, unsigned long long, unsigned long long, nvgpuAddressSpaceHandle_t *);
-RM_STATUS  NV_API_CALL  rm_gpu_ops_address_space_create_mirrored(nv_stack_t *, nvgpuSessionHandle_t, unsigned long long, unsigned long long, nvgpuAddressSpaceHandle_t *);
-RM_STATUS  NV_API_CALL  rm_gpu_ops_address_space_destroy(nv_stack_t *, nvgpuAddressSpaceHandle_t);
-RM_STATUS  NV_API_CALL  rm_gpu_ops_memory_alloc_fb(nv_stack_t *, nvgpuAddressSpaceHandle_t, NvLength, NvU64 *);
-RM_STATUS  NV_API_CALL  rm_gpu_ops_memory_alloc_sys(nv_stack_t *, nvgpuAddressSpaceHandle_t, NvLength, NvU64 *);
-RM_STATUS  NV_API_CALL  rm_gpu_ops_memory_cpu_map(nv_stack_t *, nvgpuAddressSpaceHandle_t, NvU64, NvLength, void **);
-RM_STATUS  NV_API_CALL  rm_gpu_ops_memory_cpu_ummap(nv_stack_t *, nvgpuAddressSpaceHandle_t, void*);
-RM_STATUS  NV_API_CALL  rm_gpu_ops_channel_allocate(nv_stack_t *, nvgpuAddressSpaceHandle_t, nvgpuChannelHandle_t *, nvgpuChannelInfo_t);
-RM_STATUS  NV_API_CALL  rm_gpu_ops_channel_destroy(nv_stack_t *, nvgpuChannelHandle_t);
-const char*  NV_API_CALL  rm_gpu_ops_channel_translate_error(nv_stack_t *, NvU32);
-RM_STATUS  NV_API_CALL  rm_gpu_ops_copy_engine_allocate(nv_stack_t *, nvgpuChannelHandle_t, NvU32, NvU32*, nvgpuObjectHandle_t *);
-RM_STATUS  NV_API_CALL rm_gpu_ops_memory_free(nv_stack_t *, nvgpuAddressSpaceHandle_t, NvU64);
-RM_STATUS  NV_API_CALL rm_gpu_ops_query_caps(nv_stack_t *, nvgpuAddressSpaceHandle_t, nvgpuCaps_t);
-RM_STATUS  NV_API_CALL rm_gpu_ops_get_attached_uuids(nv_stack_t *, NvU8 *pUuidList, unsigned *numGpus);
-RM_STATUS  NV_API_CALL rm_gpu_ops_get_gpu_arch(nv_stack_t *, NvU8 *pUuid, unsigned uuidLength, NvU32 *pGpuArch);
-RM_STATUS  NV_API_CALL rm_gpu_ops_get_uvm_priv_region(NvU64 *pPrivRegionStart, NvU64 *pPrivRegionLength);
-RM_STATUS  NV_API_CALL rm_gpu_ops_service_device_interrupts_rm(nv_stack_t *, nvgpuChannelHandle_t);
-RM_STATUS  NV_API_CALL rm_gpu_ops_check_ecc_error_slowpath(nv_stack_t *, nvgpuChannelHandle_t, NvBool *);
-RM_STATUS  NV_API_CALL rm_gpu_ops_kill_channel(nv_stack_t *, nvgpuChannelHandle_t);
+NV_STATUS  NV_API_CALL  rm_gpu_ops_create_session (nvidia_stack_t *, nvgpuSessionHandle_t *);
+NV_STATUS  NV_API_CALL  rm_gpu_ops_destroy_session (nvidia_stack_t *, nvgpuSessionHandle_t);
+NV_STATUS  NV_API_CALL  rm_gpu_ops_address_space_create(nvidia_stack_t *, nvgpuSessionHandle_t, unsigned long long, unsigned long long, nvgpuAddressSpaceHandle_t *, unsigned long long, unsigned long long);
+NV_STATUS  NV_API_CALL  rm_gpu_ops_address_space_create_mirrored(nvidia_stack_t *, nvgpuSessionHandle_t, unsigned long long, unsigned long long, nvgpuAddressSpaceHandle_t *);
+NV_STATUS  NV_API_CALL  rm_gpu_ops_address_space_destroy(nvidia_stack_t *, nvgpuAddressSpaceHandle_t);
+NV_STATUS  NV_API_CALL  rm_gpu_ops_memory_alloc_fb(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvLength, NvU64 *, nvgpuAllocInfo_t);
+NV_STATUS  NV_API_CALL  rm_gpu_ops_memory_alloc_sys(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvLength, NvU64 *, nvgpuAllocInfo_t);
+NV_STATUS  NV_API_CALL  rm_gpu_ops_memory_cpu_map(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvU64, NvLength, void **);
+NV_STATUS  NV_API_CALL  rm_gpu_ops_memory_cpu_ummap(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, void*);
+NV_STATUS  NV_API_CALL  rm_gpu_ops_channel_allocate(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, nvgpuChannelHandle_t *, nvgpuChannelInfo_t);
+NV_STATUS  NV_API_CALL  rm_gpu_ops_channel_destroy(nvidia_stack_t *, nvgpuChannelHandle_t);
+const char*  NV_API_CALL  rm_gpu_ops_channel_translate_error(nvidia_stack_t *, NvU32);
+NV_STATUS  NV_API_CALL  rm_gpu_ops_copy_engine_allocate(nvidia_stack_t *, nvgpuChannelHandle_t, NvU32, NvU32*, nvgpuObjectHandle_t *);
+NV_STATUS  NV_API_CALL rm_gpu_ops_memory_free(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvU64);
+NV_STATUS  NV_API_CALL rm_gpu_ops_query_caps(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, nvgpuCaps_t);
+NV_STATUS  NV_API_CALL rm_gpu_ops_get_attached_uuids(nvidia_stack_t *, NvU8 *pUuidList, unsigned *numGpus);
+NV_STATUS  NV_API_CALL rm_gpu_ops_get_gpu_arch(nvidia_stack_t *, NvU8 *pUuid, unsigned uuidLength, NvU32 *pGpuArch);
+NV_STATUS  NV_API_CALL rm_gpu_ops_get_uvm_priv_region(NvU64 *pPrivRegionStart, NvU64 *pPrivRegionLength);
+NV_STATUS  NV_API_CALL rm_gpu_ops_service_device_interrupts_rm(nvidia_stack_t *, nvgpuChannelHandle_t);
+NV_STATUS  NV_API_CALL rm_gpu_ops_check_ecc_error_slowpath(nvidia_stack_t *, nvgpuChannelHandle_t, NvBool *);
+NV_STATUS  NV_API_CALL rm_gpu_ops_kill_channel(nvidia_stack_t *, nvgpuChannelHandle_t);
+NV_STATUS  NV_API_CALL rm_gpu_ops_get_gmmu_fmt(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, void **);
 
 #endif /* NVWATCH */
 
