@@ -1,6 +1,6 @@
 /* _NVRM_COPYRIGHT_BEGIN_
  *
- * Copyright 2001-2013 by NVIDIA Corporation.  All rights reserved.  All
+ * Copyright 2001-2014 by NVIDIA Corporation.  All rights reserved.  All
  * information contained herein is proprietary and confidential to NVIDIA
  * Corporation.  Any use, reproduction, or disclosure without the written
  * permission of NVIDIA Corporation is prohibited.
@@ -16,14 +16,14 @@
 MALLOC_DEFINE(M_NVIDIA, "nvidia", "NVIDIA memory allocations");
 TASKQUEUE_DEFINE_THREAD(nvidia);
 
-RM_STATUS NV_API_CALL os_alloc_mem(
+NV_STATUS NV_API_CALL os_alloc_mem(
     void **address,
     NvU32 size
 )
 {
     /* XXX Fix me? (malloc flags) */
     *address = malloc(size, M_NVIDIA, M_NOWAIT | M_ZERO);
-    return *address ? RM_OK : RM_ERROR;
+    return *address ? NV_OK : NV_ERR_GENERIC;
 }
 
 void NV_API_CALL os_free_mem(void *address)
@@ -36,7 +36,7 @@ void NV_API_CALL os_free_mem(void *address)
 #define NV_USECS_PER_TICK       (1000000 / hz)
 #define NV_USECS_TO_TICKS(us)   ((us) * hz / 1000000)
 
-RM_STATUS NV_API_CALL os_delay(NvU32 MilliSeconds)
+NV_STATUS NV_API_CALL os_delay(NvU32 MilliSeconds)
 {
     unsigned long MicroSeconds;
     unsigned long ticks;
@@ -45,11 +45,11 @@ RM_STATUS NV_API_CALL os_delay(NvU32 MilliSeconds)
     getmicrotime(&tv_aux);
 
     if (__NV_ITHREAD() && (MilliSeconds > NV_MAX_ISR_DELAY_MS))
-        return RM_ERROR;
+        return NV_ERR_GENERIC;
 
     if (__NV_ITHREAD()) {
         DELAY(MilliSeconds * 1000);
-        return RM_OK;
+        return NV_OK;
     }
 
     MicroSeconds = MilliSeconds * 1000;
@@ -76,15 +76,15 @@ RM_STATUS NV_API_CALL os_delay(NvU32 MilliSeconds)
     if (MicroSeconds > 0)
         DELAY(MicroSeconds);
 
-    return RM_OK;
+    return NV_OK;
 }
 
-RM_STATUS NV_API_CALL os_delay_us(NvU32 MicroSeconds)
+NV_STATUS NV_API_CALL os_delay_us(NvU32 MicroSeconds)
 {
     if (__NV_ITHREAD() && (MicroSeconds > NV_MAX_ISR_DELAY_US))
-        return RM_ERROR;
+        return NV_ERR_GENERIC;
     DELAY(MicroSeconds);
-    return RM_OK;
+    return NV_OK;
 }
 
 NvU64 NV_API_CALL os_get_cpu_frequency(void)
@@ -98,17 +98,17 @@ NvU32 NV_API_CALL os_get_current_process(void)
     return curproc->p_pid;
 }
 
-RM_STATUS NV_API_CALL os_get_current_thread(NvU64 *threadId)
+NV_STATUS NV_API_CALL os_get_current_thread(NvU64 *threadId)
 {
     if (__NV_ITHREAD())
         *threadId = 0;
     else
         *threadId = (NvU64) CURTHREAD->td_tid;
 
-    return RM_OK;
+    return NV_OK;
 }
 
-RM_STATUS NV_API_CALL os_get_current_time(
+NV_STATUS NV_API_CALL os_get_current_time(
     NvU32 *sec,
     NvU32 *usec
 )
@@ -120,7 +120,7 @@ RM_STATUS NV_API_CALL os_get_current_time(
     *sec  = tv.tv_sec;
     *usec = tv.tv_usec;
 
-    return RM_OK;
+    return NV_OK;
 }
 
 BOOL NV_API_CALL os_is_administrator(PHWINFO pDev)
@@ -182,7 +182,8 @@ void NV_API_CALL os_io_write_dword(
 void* NV_API_CALL os_map_kernel_space(
     NvU64 start,
     NvU64 size,
-    NvU32 mode
+    NvU32 mode,
+    NvU32 memType
 )
 {
     int map_mode;
@@ -255,14 +256,14 @@ NvU32 cur_debuglevel = 0xffffffff;
 void NV_API_CALL os_dbg_init(void)
 {
     NvU32 new_debuglevel;
-    nv_stack_t *sp;
+    nvidia_stack_t *sp;
 
     NV_UMA_ZONE_ALLOC_STACK(sp);
     if (sp == NULL)
         return;
 
     if (rm_read_registry_dword(sp, NULL, "NVreg", "ResmanDebugLevel",
-            &new_debuglevel) == RM_OK) {
+            &new_debuglevel) == NV_OK) {
         if (new_debuglevel != 0xffffffff)
             cur_debuglevel = new_debuglevel;
     }
@@ -270,15 +271,15 @@ void NV_API_CALL os_dbg_init(void)
     NV_UMA_ZONE_FREE_STACK(sp);
 }
 
-RM_STATUS NV_API_CALL os_schedule(void)
+NV_STATUS NV_API_CALL os_schedule(void)
 {
-    return RM_ERR_NOT_SUPPORTED;
+    return NV_ERR_NOT_SUPPORTED;
 }
 
 static void os_execute_work_item(void *context, int pending)
 {
     nvidia_work_t *work = (nvidia_work_t *)context;
-    nv_stack_t *sp = NULL;
+    nvidia_stack_t *sp = NULL;
 
     NV_UMA_ZONE_ALLOC_STACK(sp);
     if (sp == NULL) {
@@ -292,13 +293,13 @@ static void os_execute_work_item(void *context, int pending)
     NV_UMA_ZONE_FREE_STACK(sp);
 }
 
-RM_STATUS NV_API_CALL os_queue_work_item(void *data)
+NV_STATUS NV_API_CALL os_queue_work_item(void *data)
 {
-    RM_STATUS status;
+    NV_STATUS status;
     nvidia_work_t *work;
 
     status = os_alloc_mem((void **)&work, sizeof(nvidia_work_t));
-    if (status != RM_OK)
+    if (status != NV_OK)
         return status;
 
     work->data = data;
@@ -306,13 +307,13 @@ RM_STATUS NV_API_CALL os_queue_work_item(void *data)
     TASK_INIT(&work->task, 0, os_execute_work_item, (void *)work);
     taskqueue_enqueue(taskqueue_nvidia, &work->task);
 
-    return RM_OK;
+    return NV_OK;
 }
 
-RM_STATUS NV_API_CALL os_flush_work_queue(void)
+NV_STATUS NV_API_CALL os_flush_work_queue(void)
 {
     taskqueue_run(taskqueue_nvidia);
-    return RM_OK;
+    return NV_OK;
 }
 
 void NV_API_CALL os_dbg_set_level(NvU32 new_debuglevel)
@@ -430,28 +431,22 @@ NvU8* NV_API_CALL os_mem_copy(
     return ret;
 }
 
-RM_STATUS NV_API_CALL os_memcpy_from_user(
+NV_STATUS NV_API_CALL os_memcpy_from_user(
     void *dst,
     const void *src,
     NvU32 length
 )
 {
-    if (src < (void *) VM_MAXUSER_ADDRESS)
-        return copyin(src, dst, length)  ? RM_ERR_INVALID_POINTER : RM_OK;
-
-    return os_mem_copy(dst, src, length) ? RM_ERR_INVALID_POINTER : RM_OK;
+    return copyin(src, dst, length)  ? NV_ERR_INVALID_POINTER : NV_OK;
 }
 
-RM_STATUS NV_API_CALL os_memcpy_to_user(
+NV_STATUS NV_API_CALL os_memcpy_to_user(
     void *dst,
     const void *src,
     NvU32 length
 )
 {
-    if (dst < (void *) VM_MAXUSER_ADDRESS)
-        return copyout(src, dst, length) ? RM_ERR_INVALID_POINTER : RM_OK;
-
-    return os_mem_copy(dst, src, length) ? RM_ERR_INVALID_POINTER : RM_OK;
+    return copyout(src, dst, length) ? NV_ERR_INVALID_POINTER : NV_OK;
 }
 
 void* NV_API_CALL os_mem_set(
@@ -522,21 +517,21 @@ static void wbinvd_action_func(void *arg)
     __asm__ __volatile__("wbinvd": : :"memory");
 }
 
-RM_STATUS NV_API_CALL os_flush_cpu_cache(void)
+NV_STATUS NV_API_CALL os_flush_cpu_cache(void)
 {
     smp_rendezvous(NULL, wbinvd_action_func, NULL, NULL);
     wbinvd_action_func(NULL);
-    return RM_OK;
+    return NV_OK;
 }
 #else
-RM_STATUS NV_API_CALL os_flush_cpu_cache(void)
+NV_STATUS NV_API_CALL os_flush_cpu_cache(void)
 {
     pmap_invalidate_cache();
-    return RM_OK;
+    return NV_OK;
 }
 #endif
 
-RM_STATUS NV_API_CALL os_flush_user_cache(
+NV_STATUS NV_API_CALL os_flush_user_cache(
     NvU64 start,
     NvU64 end,
     NvU64 physStart,
@@ -544,12 +539,12 @@ RM_STATUS NV_API_CALL os_flush_user_cache(
     NvU32 flags
 )
 {
-    return RM_ERR_NOT_SUPPORTED;
+    return NV_ERR_NOT_SUPPORTED;
 }
 
-RM_STATUS NV_API_CALL os_flush_cpu_cache_all(void)
+NV_STATUS NV_API_CALL os_flush_cpu_cache_all(void)
 {
-    return RM_ERR_NOT_SUPPORTED;
+    return NV_ERR_NOT_SUPPORTED;
 }
 
 static void sfence_action_func(void *arg)
@@ -563,29 +558,29 @@ void NV_API_CALL os_flush_cpu_write_combine_buffer(void)
     sfence_action_func(NULL);
 }
 
-RM_STATUS NV_API_CALL os_raise_smp_barrier(void)
+NV_STATUS NV_API_CALL os_raise_smp_barrier(void)
 {
-    return RM_ERR_NOT_SUPPORTED;
+    return NV_ERR_NOT_SUPPORTED;
 }
 
-RM_STATUS NV_API_CALL os_clear_smp_barrier(void)
+NV_STATUS NV_API_CALL os_clear_smp_barrier(void)
 {
-    return RM_ERR_NOT_SUPPORTED;
+    return NV_ERR_NOT_SUPPORTED;
 }
 
-RM_STATUS NV_API_CALL os_alloc_mutex(void **mutex)
+NV_STATUS NV_API_CALL os_alloc_mutex(void **mutex)
 {
-    RM_STATUS status;
+    NV_STATUS status;
     struct sx *sx;
 
     status = os_alloc_mem((void **)&sx, sizeof(struct sx));
-    if (status != RM_OK)
+    if (status != NV_OK)
         return status;
 
     sx_init(sx, "os.lock_sx");
     *mutex = (void *)sx;
 
-    return RM_OK;
+    return NV_OK;
 }
 
 void NV_API_CALL os_free_mutex(void *mutex)
@@ -598,29 +593,29 @@ void NV_API_CALL os_free_mutex(void *mutex)
     }
 }
 
-RM_STATUS NV_API_CALL os_acquire_mutex(void *mutex)
+NV_STATUS NV_API_CALL os_acquire_mutex(void *mutex)
 {
     struct sx *sx = mutex;
 
     if (__NV_ITHREAD())
-        return RM_ERR_INVALID_REQUEST;
+        return NV_ERR_INVALID_REQUEST;
 
     sx_xlock(sx);
 
-    return RM_OK;
+    return NV_OK;
 }
 
-RM_STATUS NV_API_CALL os_cond_acquire_mutex(void *mutex)
+NV_STATUS NV_API_CALL os_cond_acquire_mutex(void *mutex)
 {
     struct sx *sx = mutex;
 
     if (__NV_ITHREAD())
-        return RM_ERR_INVALID_REQUEST;
+        return NV_ERR_INVALID_REQUEST;
 
     if (sx_try_xlock(sx) == 0)
-        return RM_ERR_TIMEOUT_RETRY;
+        return NV_ERR_TIMEOUT_RETRY;
 
-    return RM_OK;
+    return NV_OK;
 }
 
 void NV_API_CALL os_release_mutex(void *mutex)
@@ -639,11 +634,11 @@ struct os_semaphore {
 
 void* NV_API_CALL os_alloc_semaphore(NvU32 initialValue, NvU32 limit)
 {
-    RM_STATUS status;
+    NV_STATUS status;
     struct os_semaphore *os_sema;
 
     status = os_alloc_mem((void **)&os_sema, sizeof(struct os_semaphore));
-    if (status != RM_OK) {
+    if (status != NV_OK) {
         nv_printf(NV_DBG_ERRORS, "NVRM: failed to allocate semaphore!\n");
         return NULL;
     }
@@ -667,7 +662,7 @@ void NV_API_CALL os_free_semaphore(void *semaphore)
     os_free_mem(os_sema);
 }
 
-RM_STATUS NV_API_CALL os_acquire_semaphore(void *semaphore)
+NV_STATUS NV_API_CALL os_acquire_semaphore(void *semaphore)
 {
     struct os_semaphore *os_sema = (struct os_semaphore *)semaphore;
 
@@ -678,10 +673,10 @@ RM_STATUS NV_API_CALL os_acquire_semaphore(void *semaphore)
     else
         mtx_unlock(&os_sema->mutex_mtx);
 
-    return RM_OK;
+    return NV_OK;
 }
 
-RM_STATUS NV_API_CALL os_release_semaphore(void *semaphore)
+NV_STATUS NV_API_CALL os_release_semaphore(void *semaphore)
 {
     struct os_semaphore *os_sema = (struct os_semaphore *)semaphore;
 
@@ -692,7 +687,7 @@ RM_STATUS NV_API_CALL os_release_semaphore(void *semaphore)
     os_sema->count++;
     mtx_unlock(&os_sema->mutex_mtx);
 
-    return RM_OK;
+    return NV_OK;
 }
 
 BOOL NV_API_CALL os_semaphore_may_sleep(void)
@@ -715,13 +710,13 @@ BOOL NV_API_CALL os_is_efi_enabled(void)
     return FALSE;
 }
 
-RM_STATUS NV_API_CALL os_get_efi_screen_info(
+NV_STATUS NV_API_CALL os_get_efi_screen_info(
     NvU64 *pPhysicalAddress,
     NvU32 *pHeight,
     NvU32 *pPitch
 )
 {
-    return RM_ERR_NOT_SUPPORTED;
+    return NV_ERR_NOT_SUPPORTED;
 }
 
 void NV_API_CALL os_register_compatible_ioctl(
@@ -738,30 +733,30 @@ void NV_API_CALL os_unregister_compatible_ioctl(
 {
 }
 
-RM_STATUS NV_API_CALL os_disable_console_access(void)
+NV_STATUS NV_API_CALL os_disable_console_access(void)
 {
-    return RM_OK;
+    return NV_OK;
 }
 
-RM_STATUS NV_API_CALL os_enable_console_access(void)
+NV_STATUS NV_API_CALL os_enable_console_access(void)
 {
-    return RM_OK;
+    return NV_OK;
 }
 
-RM_STATUS NV_API_CALL os_alloc_spinlock(void **lock)
+NV_STATUS NV_API_CALL os_alloc_spinlock(void **lock)
 {
-    RM_STATUS status;
+    NV_STATUS status;
     struct mtx *mtx;
 
     status = os_alloc_mem((void **)&mtx, sizeof(struct mtx));
-    if (status != RM_OK)
+    if (status != NV_OK)
         return status;
 
     mtx_init(mtx, "os.lock_mtx", NULL, MTX_DEF);
 
     *lock = (void *)mtx;
 
-    return RM_OK;
+    return NV_OK;
 }
 
 void NV_API_CALL os_free_spinlock(void *lock)
@@ -791,29 +786,29 @@ void NV_API_CALL os_release_spinlock(void *lock, NvU64 oldIrql)
     mtx_unlock(mtx);
 }
 
-RM_STATUS NV_API_CALL os_get_address_space_info(
+NV_STATUS NV_API_CALL os_get_address_space_info(
     NvU64 *userStartAddress,
     NvU64 *userEndAddress,
     NvU64 *kernelStartAddress,
     NvU64 *kernelEndAddress
 )
 {
-    return RM_ERR_NOT_SUPPORTED;
+    return NV_ERR_NOT_SUPPORTED;
 }
 
-RM_STATUS NV_API_CALL os_alloc_smp_barrier(void)
+NV_STATUS NV_API_CALL os_alloc_smp_barrier(void)
 {
-    return RM_OK;
+    return NV_OK;
 }
 
-RM_STATUS NV_API_CALL os_free_smp_barrier(void)
+NV_STATUS NV_API_CALL os_free_smp_barrier(void)
 {
-    return RM_OK;
+    return NV_OK;
 }
 
-RM_STATUS NV_API_CALL os_get_version_info(os_version_info * pOsVersionInfo)
+NV_STATUS NV_API_CALL os_get_version_info(os_version_info * pOsVersionInfo)
 {
-    return RM_ERR_NOT_SUPPORTED;
+    return NV_ERR_NOT_SUPPORTED;
 }
 
 NvBool NV_API_CALL os_is_xen_dom0(void)
@@ -826,28 +821,42 @@ NvBool NV_API_CALL os_is_vgx_hyper(void)
     return FALSE;
 }
 
+NV_STATUS NV_API_CALL os_inject_vgx_msi(NvU16 guestID, NvU64 msiAddr, NvU32 msiData)
+{
+    return NV_ERR_NOT_SUPPORTED;  
+}
+
 void NV_API_CALL os_bug_check(NvU32 bugCode, const char *bugCodeStr)
 {
 }
 
-RM_STATUS NV_API_CALL os_lock_user_pages(
+NV_STATUS NV_API_CALL os_lock_user_pages(
     void   *address,
     NvU64   page_count,
     void  **page_array
 )
 {
-    return RM_ERR_NOT_SUPPORTED;
+    return NV_ERR_NOT_SUPPORTED;
 }
 
-RM_STATUS NV_API_CALL os_unlock_user_pages(
+NV_STATUS NV_API_CALL os_unlock_user_pages(
     NvU64  page_count,
     void  *page_array
 )
 {
-    return RM_ERR_NOT_SUPPORTED;
+    return NV_ERR_NOT_SUPPORTED;
 }
 
-RM_STATUS NV_API_CALL os_match_mmap_offset(
+NV_STATUS NV_API_CALL os_lookup_user_io_memory(
+    void   *address,
+    NvU64   page_count,
+    NvU64 **pte_array
+)
+{
+    return NV_ERR_NOT_SUPPORTED;
+}
+
+NV_STATUS NV_API_CALL os_match_mmap_offset(
     void  *pAllocPrivate,
     NvU64  offset,
     NvU64 *pPageIndex
@@ -860,15 +869,15 @@ RM_STATUS NV_API_CALL os_match_mmap_offset(
         if (at->alloc_type_contiguous) {
             if (offset == (at->pte_array[0].physical_address + (i * PAGE_SIZE))) {
                 *pPageIndex = i;
-                return RM_OK;
+                return NV_OK;
             }
         } else {
             if (offset == at->pte_array[i].physical_address) {
                 *pPageIndex = i;
-                return RM_OK;
+                return NV_OK;
             }
         }
     }
 
-    return RM_ERR_OBJECT_NOT_FOUND;
+    return NV_ERR_OBJECT_NOT_FOUND;
 }
