@@ -31,7 +31,7 @@ int nvidia_pci_probe(device_t dev)
 {
     NvU16 device;
     char name[NV_DEVICE_NAME_LENGTH];
-    nv_stack_t *sp;
+    nvidia_stack_t *sp;
     NvU16 subvendor, subdevice;
 
     device = pci_get_device(dev);
@@ -59,7 +59,7 @@ int nvidia_pci_probe(device_t dev)
 
     if (rm_get_device_name(sp, NULL, device, subvendor, subdevice,
                 NV_DEVICE_NAME_LENGTH, name)
-            != RM_OK) {
+            != NV_OK) {
         strcpy(name, "Unknown");
     }
 
@@ -124,8 +124,42 @@ static void nvidia_pci_enable_intx(device_t dev)
     os_pci_write_word(dev, PCIR_COMMAND, word);
 }
 
-void nvidia_pci_check_config_space(
+void nvidia_pci_save_config_space(
     nv_stack_t *sp,
+    device_t dev
+)
+{
+    struct nvidia_softc *sc = device_get_softc(dev);
+    nv_state_t *nv = sc->nv_state;
+    NvS16 i;
+
+    for (i = 0; i < NVRM_PCICFG_NUM_DWORDS; i++)
+    {
+        os_pci_read_dword(dev, (i << 2), &nv->pci_cfg_space[i]);
+    }
+}
+
+void nvidia_pci_restore_config_space(
+    nv_stack_t *sp,
+    device_t dev
+)
+{
+    struct nvidia_softc *sc = device_get_softc(dev);
+    nv_state_t *nv = sc->nv_state;
+    NvS16 i;
+    NvU32 dword;
+
+    for (i = NVRM_PCICFG_NUM_DWORDS - 1; i >= 0; i--)
+    {
+        os_pci_read_dword(dev, (i << 2), &dword);
+        if (dword != nv->pci_cfg_space[i]) {
+            os_pci_write_dword(dev, (i << 2), nv->pci_cfg_space[i]);
+        }
+    }
+}
+
+void nvidia_pci_check_config_space(
+    nvidia_stack_t *sp,
     device_t dev,
     BOOL check_the_bars,
     BOOL acquire_semaphore,
@@ -227,7 +261,7 @@ int nvidia_pci_attach(device_t dev)
     NvU16 word, i, j;
     NvU32 BAR_low, req;
     NvU64 BAR_high;
-    nv_stack_t *sp;
+    nvidia_stack_t *sp;
 
     if (device_get_unit(dev) >= NV_MAX_DEVICES) {
         device_printf(dev, "NVRM: maximum device number exceeded.\n");
@@ -333,7 +367,7 @@ fail:
 int nvidia_pci_detach(device_t dev)
 {
     int status;
-    nv_stack_t *sp;
+    nvidia_stack_t *sp;
     struct nvidia_softc *sc;
     nv_state_t *nv;
 
