@@ -1,6 +1,6 @@
 /* _NVRM_COPYRIGHT_BEGIN_
  *
- * Copyright 2001-2013 by NVIDIA Corporation.  All rights reserved.  All
+ * Copyright 2001-2014 by NVIDIA Corporation.  All rights reserved.  All
  * information contained herein is proprietary and confidential to NVIDIA
  * Corporation.  Any use, reproduction, or disclosure without the written
  * permission of NVIDIA Corporation is prohibited.
@@ -18,14 +18,14 @@
 #endif
 
 uma_zone_t nvidia_stack_t_zone;
-static nv_stack_t *__nvidia_init_sp = NULL;
+static nvidia_stack_t *__nvidia_init_sp = NULL;
 
 devclass_t nvidia_devclass;
 nv_state_t nvidia_ctl_state;
 
 int nvidia_attach(device_t dev)
 {
-    RM_STATUS status;
+    NV_STATUS status;
     NvU32 i, pmc_boot_0, pmc_boot_42;
     struct nvidia_softc *sc;
     nv_state_t *nv;
@@ -56,9 +56,9 @@ int nvidia_attach(device_t dev)
     pci_enable_io(dev, SYS_RES_MEMORY);
 
     if ((status = rm_is_supported_device(sc->attach_sp, nv, &pmc_boot_0,
-                                         &pmc_boot_42)) != RM_OK)
+                                         &pmc_boot_42)) != NV_OK)
     {
-        if ((status != RM_ERR_NOT_SUPPORTED) ||
+        if ((status != NV_ERR_NOT_SUPPORTED) ||
             !rm_is_legacy_arch(pmc_boot_0, pmc_boot_42))
         {
             nv_printf(NV_DBG_ERRORS,
@@ -172,7 +172,7 @@ failed:
 #ifdef NV_SUPPORT_ACPI_PM
 int nvidia_suspend(device_t dev)
 {
-    nv_stack_t *sp;
+    nvidia_stack_t *sp;
     struct nvidia_softc *sc;
     nv_state_t *nv;
     int status;
@@ -191,14 +191,16 @@ int nvidia_suspend(device_t dev)
     NV_PCI_CHECK_CONFIG_SPACE(sp, nv, TRUE, TRUE, TRUE);
     status = rm_power_management(sp, nv, 0, NV_PM_ACPI_STANDBY);
 
+    nvidia_pci_save_config_space(sp, dev);
+
     NV_UMA_ZONE_FREE_STACK(sp);
 
-    return (status == RM_OK) ? 0 : EIO;
+    return (status == NV_OK) ? 0 : EIO;
 }
 
 int nvidia_resume(device_t dev)
 {
-    nv_stack_t *sp;
+    nvidia_stack_t *sp;
     struct nvidia_softc *sc;
     nv_state_t *nv;
     int status;
@@ -207,6 +209,8 @@ int nvidia_resume(device_t dev)
     if (sp == NULL)
         return ENOMEM;
 
+    nvidia_pci_restore_config_space(sp, dev);
+
     sc = device_get_softc(dev);
     nv = sc->nv_state;
 
@@ -215,7 +219,7 @@ int nvidia_resume(device_t dev)
 
     NV_UMA_ZONE_FREE_STACK(sp);
 
-    return (status == RM_OK) ? 0 : EIO;
+    return (status == NV_OK) ? 0 : EIO;
 }
 #endif /* NV_SUPPORT_ACPI_PM */
 
@@ -227,7 +231,7 @@ int nvidia_alloc_hardware(device_t dev)
     NvU32 flags, i;
     NvU32 enable_msi = 0;
     int count;
-    nv_stack_t *sp;
+    nvidia_stack_t *sp;
 
     NV_UMA_ZONE_ALLOC_STACK(sp);
     if (sp == NULL)
@@ -261,7 +265,7 @@ int nvidia_alloc_hardware(device_t dev)
     }
 
     if ((rm_read_registry_dword(sp, NULL, "NVreg",
-            "EnableMSI", &enable_msi) == RM_OK) && (enable_msi != 0)) {
+            "EnableMSI", &enable_msi) == NV_OK) && (enable_msi != 0)) {
         count = pci_msi_count(dev);
         if ((count == 1) && (pci_alloc_msi(dev, &count) == 0))
             sc->irq_rid = 1;
@@ -301,7 +305,7 @@ void nvidia_intr(void *xsc)
     struct nvidia_softc *sc;
     nv_state_t *nv;
     NvU32 run_bottom_half = 0;
-    nv_stack_t *sp;
+    nvidia_stack_t *sp;
 
     sc = (struct nvidia_softc *) xsc;
     nv = sc->nv_state;
@@ -394,7 +398,7 @@ int nvidia_handle_ioctl(
 )
 {
     struct nvidia_softc *sc;
-    nv_stack_t *sp;
+    nvidia_stack_t *sp;
     void *args;
     nv_ioctl_xfer_t *xfer = NULL;
     int status;
@@ -435,7 +439,7 @@ int nvidia_handle_ioctl(
     switch (nr) {
         case NV_ESC_CHECK_VERSION_STR:
             status = ((rm_perform_version_check(sp,
-                            args, size) == RM_OK) ? 0 : EINVAL);
+                            args, size) == NV_OK) ? 0 : EINVAL);
             break;
 
         case NV_ESC_CARD_INFO:
@@ -444,7 +448,7 @@ int nvidia_handle_ioctl(
 
         default:
             status = ((rm_ioctl(sp, nv, filep, nr,
-                            args, size) == RM_OK) ? 0 : EINVAL);
+                            args, size) == NV_OK) ? 0 : EINVAL);
             break;
     }
 
@@ -482,7 +486,7 @@ int nvidia_close_ctl(
 )
 {
     struct nvidia_softc *sc = nv->os_state;
-    nv_stack_t *sp;
+    nvidia_stack_t *sp;
 
     sp = sc->api_sp;
     rm_free_unused_clients(sp, nv, filep);
@@ -502,7 +506,7 @@ int nvidia_open_dev(
 {
     int status = ENOMEM;
     struct nvidia_softc *sc = nv->os_state;
-    nv_stack_t *sp = NULL;
+    nvidia_stack_t *sp = NULL;
 
     if (sc->refcnt == 0) {
         NV_UMA_ZONE_ALLOC_STACK(sc->api_sp);
@@ -586,7 +590,7 @@ int nvidia_close_dev(
 )
 {
     struct nvidia_softc *sc;
-    nv_stack_t *sp;
+    nvidia_stack_t *sp;
 
     sc = nv->os_state;
     sp = sc->api_sp;
@@ -622,7 +626,7 @@ int nvidia_modevent(
 {
     nv_state_t *nv;
     struct nvidia_softc *sc;
-    nv_stack_t *sp;
+    nvidia_stack_t *sp;
 
     switch (what) {
         case MOD_LOAD:
@@ -634,7 +638,7 @@ int nvidia_modevent(
              */
             sc = &nvidia_ctl_sc;
 
-            nvidia_stack_t_zone = uma_zcreate("nv_stack_t", sizeof(nv_stack_t),
+            nvidia_stack_t_zone = uma_zcreate("nvidia_stack_t", sizeof(nvidia_stack_t),
                     NULL, NULL, NULL, NULL, UMA_ALIGN_PTR, 0);
             if (nvidia_stack_t_zone == NULL)
                 return ENOMEM;
@@ -725,9 +729,9 @@ void nv_unlock_api(nv_state_t *nv)
 void NV_API_CALL nv_post_event(
     nv_state_t *nv,
     nv_event_t *event,
-    NvU32 hObject,
-    NvU32 index,
-    NvBool data_valid
+    NvHandle    hObject,
+    NvU32       index,
+    NvBool      data_valid
 )
 {
     struct nvidia_filep *filep = event->file;
@@ -770,7 +774,7 @@ NvS32 NV_API_CALL nv_get_event(
     et = STAILQ_FIRST(&filep->event_queue);
     if (et == NULL) {
         mtx_unlock(&filep->event_mtx);
-        return RM_ERROR;
+        return NV_ERR_GENERIC;
     }
 
     *event = et->event;
@@ -783,7 +787,7 @@ NvS32 NV_API_CALL nv_get_event(
 
     free(et, M_NVIDIA);
 
-    return RM_OK;
+    return NV_OK;
 }
 
 void* NV_API_CALL nv_alloc_kernel_mapping(
@@ -833,7 +837,7 @@ void* NV_API_CALL nv_alloc_kernel_mapping(
     return (void *)(virtual_address + pageOffset);
 }
 
-RM_STATUS NV_API_CALL nv_free_kernel_mapping(
+NV_STATUS NV_API_CALL nv_free_kernel_mapping(
     nv_state_t *nv,
     void       *pAllocPrivate,
     void       *address,
@@ -850,10 +854,10 @@ RM_STATUS NV_API_CALL nv_free_kernel_mapping(
             (virtual_address + size));
     }
 
-    return RM_OK;
+    return NV_OK;
 }
 
-RM_STATUS NV_API_CALL nv_create_user_mapping_context(
+NV_STATUS NV_API_CALL nv_create_user_mapping_context(
     nv_state_t *nv,
     NvU64 address,
     NvU64 size,
@@ -861,10 +865,10 @@ RM_STATUS NV_API_CALL nv_create_user_mapping_context(
 )
 {
     *ppPrivate = NULL;
-    return RM_OK;
+    return NV_OK;
 }
 
-RM_STATUS NV_API_CALL nv_alloc_user_mapping(
+NV_STATUS NV_API_CALL nv_alloc_user_mapping(
     nv_state_t *nv,
     void       *pAllocPrivate,
     NvU64       pageIndex,
@@ -882,17 +886,17 @@ RM_STATUS NV_API_CALL nv_alloc_user_mapping(
     else
         *pUserAddress = (at->pte_array[pageIndex].physical_address + pageOffset);
 
-    return RM_OK;
+    return NV_OK;
 }
 
-RM_STATUS NV_API_CALL nv_free_user_mapping(
+NV_STATUS NV_API_CALL nv_free_user_mapping(
     nv_state_t *nv,
     void       *pAllocPrivate,
     NvU64       userAddress,
     void       *pPrivate
 )
 {
-    return RM_OK;
+    return NV_OK;
 }
 
 NvS32 nv_alloc_contig_pages(
@@ -1178,7 +1182,7 @@ NvS32 nv_free_system_pages(
     return 0;
 }
 
-RM_STATUS NV_API_CALL nv_alias_pages(
+NV_STATUS NV_API_CALL nv_alias_pages(
     nv_state_t *nv,
     NvU32       count,
     NvU32       alloc_type_contiguous,
@@ -1188,10 +1192,10 @@ RM_STATUS NV_API_CALL nv_alias_pages(
     void      **priv_data
 )
 {
-    return RM_ERR_NOT_SUPPORTED;
+    return NV_ERR_NOT_SUPPORTED;
 }
 
-RM_STATUS NV_API_CALL nv_alloc_pages(
+NV_STATUS NV_API_CALL nv_alloc_pages(
     nv_state_t *nv,
     NvU32       count,
     NvBool      alloc_type_contiguous,
@@ -1201,25 +1205,25 @@ RM_STATUS NV_API_CALL nv_alloc_pages(
     void      **private
 )
 {
-    RM_STATUS status = RM_OK;
+    NV_STATUS status = NV_OK;
     NvBool zero = alloc_type_zeroed;
 
     if (!alloc_type_contiguous) {
         if (nv_alloc_system_pages(nv, count, cache_type, zero,
                     pte_array, private)) {
-            status = RM_ERR_NO_MEMORY;
+            status = NV_ERR_NO_MEMORY;
         }
     } else {
         if (nv_alloc_contig_pages(nv, count, cache_type, zero,
                     pte_array, private)) {
-            status = RM_ERR_NO_MEMORY;
+            status = NV_ERR_NO_MEMORY;
         }
     }
 
     return status;
 }
 
-RM_STATUS NV_API_CALL nv_free_pages(
+NV_STATUS NV_API_CALL nv_free_pages(
     nv_state_t *nv,
     NvU32 count,
     NvBool alloc_type_contiguous,
@@ -1227,14 +1231,14 @@ RM_STATUS NV_API_CALL nv_free_pages(
     void *private
 )
 {
-    RM_STATUS status = RM_OK;
+    NV_STATUS status = NV_OK;
 
     if (!alloc_type_contiguous) {
         if (nv_free_system_pages(nv, private))
-            status = RM_ERROR;
+            status = NV_ERR_GENERIC;
     } else  {
         if (nv_free_contig_pages(nv, private))
-            status = RM_ERROR;
+            status = NV_ERR_GENERIC;
     }
 
     return status;
@@ -1280,8 +1284,8 @@ int nvidia_mmap_ctl_single(
 )
 {
     struct nvidia_alloc *at;
-    nv_stack_t *sp;
-    RM_STATUS rmStatus;
+    nvidia_stack_t *sp;
+    NV_STATUS rmStatus;
     struct nvidia_softc *sc = nv->os_state;
     NvU64 pageIndex;
     NvU32 prot;
@@ -1289,12 +1293,12 @@ int nvidia_mmap_ctl_single(
     sp = sc->api_sp;
 
     rmStatus = rm_acquire_api_lock(sp);
-    if (rmStatus != RM_OK)
+    if (rmStatus != NV_OK)
         return EAGAIN;
 
     rmStatus = rm_validate_mmap_request(sp, nv, filep, *offset,
             size, &prot, (void **)&at, &pageIndex);
-    if (rmStatus != RM_OK) {
+    if (rmStatus != NV_OK) {
         rm_release_api_lock(sp);
         return EINVAL;
     }
@@ -1316,8 +1320,8 @@ int nvidia_mmap_dev_single(
     vm_object_t *object
 )
 {
-    nv_stack_t *sp;
-    RM_STATUS rmStatus;
+    nvidia_stack_t *sp;
+    NV_STATUS rmStatus;
     struct nvidia_softc *sc = nv->os_state;
     NvU32 prot;
 
@@ -1327,7 +1331,7 @@ int nvidia_mmap_dev_single(
 
     rmStatus = rm_validate_mmap_request(sp, nv, filep, *offset, size,
             &prot, NULL, NULL);
-    if (rmStatus != RM_OK)
+    if (rmStatus != NV_OK)
         return EINVAL;
 
     if (IS_UD_OFFSET(nv, *offset, size)) {
@@ -1354,13 +1358,13 @@ void nvidia_rc_timer(void *data)
 {
     nv_state_t *nv = data;
     struct nvidia_softc *sc = nv->os_state;
-    nv_stack_t *sp;
+    nvidia_stack_t *sp;
 
     sp = sc->timer_sp;
 
     NV_PCI_CHECK_CONFIG_SPACE(sp, nv, TRUE, TRUE, FALSE);
 
-    if (rm_run_rc_callback(sp, nv) == RM_OK)
+    if (rm_run_rc_callback(sp, nv) == NV_OK)
         callout_reset(&sc->timer, hz, nvidia_rc_timer, (void *)nv);
 }
 
@@ -1444,7 +1448,7 @@ void NV_API_CALL nv_verify_pci_config(
 {
     struct nvidia_softc *sc = nv->os_state;
     device_t dev = sc->dev;
-    nv_stack_t *sp = sc->pci_cfgchk_sp;
+    nvidia_stack_t *sp = sc->pci_cfgchk_sp;
 
     nvidia_pci_check_config_space(sp, dev, check_the_bars, FALSE, FALSE);
 }
@@ -1454,37 +1458,37 @@ void* NV_API_CALL nv_get_smu_state(void)
     return NULL;
 }
 
-RM_STATUS NV_API_CALL nv_dma_map_pages(
+NV_STATUS NV_API_CALL nv_dma_map_pages(
     nv_state_t *nv,
     NvU64       page_count,
     NvU64      *pte_array,
     void      **priv
 )
 {
-    return RM_ERR_NOT_SUPPORTED;
+    return NV_ERR_NOT_SUPPORTED;
 }
 
-RM_STATUS NV_API_CALL nv_dma_unmap_pages(
+NV_STATUS NV_API_CALL nv_dma_unmap_pages(
     nv_state_t *nv,
     NvU64       page_count,
     NvU64      *pte_array,
     void      **priv
 )
 {
-    return RM_ERR_NOT_SUPPORTED;
+    return NV_ERR_NOT_SUPPORTED;
 }
 
-RM_STATUS NV_API_CALL nv_log_error(
+NV_STATUS NV_API_CALL nv_log_error(
     nv_state_t *nv,
     NvU32       error_number,
     const char *format,
     va_list    ap
 )
 {
-    return RM_OK;
+    return NV_OK;
 }
 
-RM_STATUS NV_API_CALL nv_alloc_os_descriptor_handle(
+NV_STATUS NV_API_CALL nv_alloc_os_descriptor_handle(
     nv_state_t *nv,
     NvS32       fd,
     void       *private,
@@ -1492,7 +1496,7 @@ RM_STATUS NV_API_CALL nv_alloc_os_descriptor_handle(
     NvU32      *handle
 )
 {
-    return RM_ERR_NOT_SUPPORTED;
+    return NV_ERR_NOT_SUPPORTED;
 }
 
 NvU64 NV_API_CALL nv_get_dma_start_address(
@@ -1501,3 +1505,17 @@ NvU64 NV_API_CALL nv_get_dma_start_address(
 {
     return 0;
 }
+
+NV_STATUS NV_API_CALL nv_set_primary_vga_status(
+    nv_state_t *nv
+)
+{
+    return NV_ERR_NOT_SUPPORTED;
+}
+
+NV_STATUS NV_API_CALL nv_pci_trigger_recovery(
+    nv_state_t *nv
+)
+{
+    return NV_ERR_NOT_SUPPORTED;
+}
