@@ -73,37 +73,37 @@ NvU32       NV_API_CALL  os_get_page_size            (void);
 NvU64       NV_API_CALL  os_get_page_mask            (void);
 NvU8        NV_API_CALL  os_get_page_shift           (void);
 NvU64       NV_API_CALL  os_get_num_phys_pages       (void);
-RM_STATUS   NV_API_CALL  os_alloc_mem                (void **, NvU32);
+NV_STATUS   NV_API_CALL  os_alloc_mem                (void **, NvU32);
 void        NV_API_CALL  os_free_mem                 (void *);
-RM_STATUS   NV_API_CALL  os_get_current_time         (NvU32 *, NvU32 *);
-RM_STATUS   NV_API_CALL  os_delay                    (NvU32);
-RM_STATUS   NV_API_CALL  os_delay_us                 (NvU32);
+NV_STATUS   NV_API_CALL  os_get_current_time         (NvU32 *, NvU32 *);
+NV_STATUS   NV_API_CALL  os_delay                    (NvU32);
+NV_STATUS   NV_API_CALL  os_delay_us                 (NvU32);
 NvU64       NV_API_CALL  os_get_cpu_frequency        (void);
 NvU32       NV_API_CALL  os_get_current_process      (void);
-RM_STATUS   NV_API_CALL  os_get_current_thread       (NvU64 *);
+NV_STATUS   NV_API_CALL  os_get_current_thread       (NvU64 *);
 char*       NV_API_CALL  os_string_copy              (char *, const char *);
 NvU32       NV_API_CALL  os_string_length            (const char *);
 NvS32       NV_API_CALL  os_snprintf                 (char *, NvU32, const char *, ...);
 void        NV_API_CALL  os_log_error                (NvU32, NvU32, const char *, va_list);
 NvU8*       NV_API_CALL  os_mem_copy                 (NvU8 *, const NvU8 *, NvU32);
-RM_STATUS   NV_API_CALL  os_memcpy_from_user         (void *, const void *, NvU32);
-RM_STATUS   NV_API_CALL  os_memcpy_to_user           (void *, const void *, NvU32);
+NV_STATUS   NV_API_CALL  os_memcpy_from_user         (void *, const void *, NvU32);
+NV_STATUS   NV_API_CALL  os_memcpy_to_user           (void *, const void *, NvU32);
 void*       NV_API_CALL  os_mem_set                  (void *, NvU8, NvU32);
 NvS32       NV_API_CALL  os_mem_cmp                  (const NvU8 *, const NvU8 *, NvU32);
 void*       NV_API_CALL  os_pci_init_handle          (NvU32, NvU8, NvU8, NvU8, NvU16 *, NvU16 *);
-RM_STATUS   NV_API_CALL  os_pci_read_byte            (void *, NvU32, NvU8 *);
-RM_STATUS   NV_API_CALL  os_pci_read_word            (void *, NvU32, NvU16 *);
-RM_STATUS   NV_API_CALL  os_pci_read_dword           (void *, NvU32, NvU32 *);
-RM_STATUS   NV_API_CALL  os_pci_write_byte           (void *, NvU32, NvU8);
-RM_STATUS   NV_API_CALL  os_pci_write_word           (void *, NvU32, NvU16);
-RM_STATUS   NV_API_CALL  os_pci_write_dword          (void *, NvU32, NvU32);
-void*       NV_API_CALL  os_map_kernel_space         (NvU64, NvU64, NvU32);
+NV_STATUS   NV_API_CALL  os_pci_read_byte            (void *, NvU32, NvU8 *);
+NV_STATUS   NV_API_CALL  os_pci_read_word            (void *, NvU32, NvU16 *);
+NV_STATUS   NV_API_CALL  os_pci_read_dword           (void *, NvU32, NvU32 *);
+NV_STATUS   NV_API_CALL  os_pci_write_byte           (void *, NvU32, NvU8);
+NV_STATUS   NV_API_CALL  os_pci_write_word           (void *, NvU32, NvU16);
+NV_STATUS   NV_API_CALL  os_pci_write_dword          (void *, NvU32, NvU32);
+void*       NV_API_CALL  os_map_kernel_space         (NvU64, NvU64, NvU32, NvU32);
 void        NV_API_CALL  os_unmap_kernel_space       (void *, NvU64);
 void*       NV_API_CALL  os_map_user_space           (NvU64, NvU64, NvU32, NvU32, void **);
 void        NV_API_CALL  os_unmap_user_space         (void *, NvU64, void *);
-RM_STATUS   NV_API_CALL  os_flush_cpu_cache          (void);
-RM_STATUS   NV_API_CALL  os_flush_cpu_cache_all      (void);
-RM_STATUS   NV_API_CALL  os_flush_user_cache         (NvU64, NvU64, NvU64, NvU64, NvU32);
+NV_STATUS   NV_API_CALL  os_flush_cpu_cache          (void);
+NV_STATUS   NV_API_CALL  os_flush_cpu_cache_all      (void);
+NV_STATUS   NV_API_CALL  os_flush_user_cache         (NvU64, NvU64, NvU64, NvU64, NvU32);
 void        NV_API_CALL  os_flush_cpu_write_combine_buffer(void);
 NvU8        NV_API_CALL  os_io_read_byte             (NvU32);
 NvU16       NV_API_CALL  os_io_read_word             (NvU32);
@@ -117,45 +117,47 @@ void        NV_API_CALL  os_dbg_breakpoint           (void);
 void        NV_API_CALL  os_dbg_set_level            (NvU32);
 NvU32       NV_API_CALL  os_get_cpu_count            (void);
 NvU32       NV_API_CALL  os_get_cpu_number           (void);
-RM_STATUS   NV_API_CALL  os_alloc_smp_barrier        (void);
-RM_STATUS   NV_API_CALL  os_free_smp_barrier         (void);
-RM_STATUS   NV_API_CALL  os_raise_smp_barrier        (void);
-RM_STATUS   NV_API_CALL  os_clear_smp_barrier        (void);
-RM_STATUS   NV_API_CALL  os_disable_console_access   (void);
-RM_STATUS   NV_API_CALL  os_enable_console_access    (void);
-RM_STATUS   NV_API_CALL  os_registry_init            (void);
-RM_STATUS   NV_API_CALL  os_schedule                 (void);
-RM_STATUS   NV_API_CALL  os_alloc_spinlock           (void **);
+NV_STATUS   NV_API_CALL  os_alloc_smp_barrier        (void);
+NV_STATUS   NV_API_CALL  os_free_smp_barrier         (void);
+NV_STATUS   NV_API_CALL  os_raise_smp_barrier        (void);
+NV_STATUS   NV_API_CALL  os_clear_smp_barrier        (void);
+NV_STATUS   NV_API_CALL  os_disable_console_access   (void);
+NV_STATUS   NV_API_CALL  os_enable_console_access    (void);
+NV_STATUS   NV_API_CALL  os_registry_init            (void);
+NV_STATUS   NV_API_CALL  os_schedule                 (void);
+NV_STATUS   NV_API_CALL  os_alloc_spinlock           (void **);
 void        NV_API_CALL  os_free_spinlock            (void *);
 NvU64       NV_API_CALL  os_acquire_spinlock         (void *);
 void        NV_API_CALL  os_release_spinlock         (void *, NvU64);
-RM_STATUS   NV_API_CALL  os_get_address_space_info   (NvU64 *, NvU64 *, NvU64 *, NvU64 *);
-RM_STATUS   NV_API_CALL  os_queue_work_item          (void *);
-RM_STATUS   NV_API_CALL  os_flush_work_queue         (void);
+NV_STATUS   NV_API_CALL  os_get_address_space_info   (NvU64 *, NvU64 *, NvU64 *, NvU64 *);
+NV_STATUS   NV_API_CALL  os_queue_work_item          (void *);
+NV_STATUS   NV_API_CALL  os_flush_work_queue         (void);
 void        NV_API_CALL  os_register_compatible_ioctl    (NvU32, NvU32);
 void        NV_API_CALL  os_unregister_compatible_ioctl  (NvU32, NvU32);
-RM_STATUS   NV_API_CALL  os_alloc_mutex              (void **);
+NV_STATUS   NV_API_CALL  os_alloc_mutex              (void **);
 void        NV_API_CALL  os_free_mutex               (void *);
-RM_STATUS   NV_API_CALL  os_acquire_mutex            (void *);
-RM_STATUS   NV_API_CALL  os_cond_acquire_mutex       (void *);
+NV_STATUS   NV_API_CALL  os_acquire_mutex            (void *);
+NV_STATUS   NV_API_CALL  os_cond_acquire_mutex       (void *);
 void        NV_API_CALL  os_release_mutex            (void *);
 void*       NV_API_CALL  os_alloc_semaphore          (NvU32, NvU32);
 void        NV_API_CALL  os_free_semaphore           (void *);
-RM_STATUS   NV_API_CALL  os_acquire_semaphore        (void *);
-RM_STATUS   NV_API_CALL  os_release_semaphore        (void *);
+NV_STATUS   NV_API_CALL  os_acquire_semaphore        (void *);
+NV_STATUS   NV_API_CALL  os_release_semaphore        (void *);
 BOOL        NV_API_CALL  os_semaphore_may_sleep      (void);
-RM_STATUS   NV_API_CALL  os_get_version_info         (os_version_info*);
+NV_STATUS   NV_API_CALL  os_get_version_info         (os_version_info*);
 BOOL        NV_API_CALL  os_is_isr                   (void);
 BOOL        NV_API_CALL  os_pat_supported            (void);
 void        NV_API_CALL  os_dump_stack               (void);
 BOOL        NV_API_CALL  os_is_efi_enabled           (void);
 NvBool      NV_API_CALL  os_is_xen_dom0              (void);
 NvBool      NV_API_CALL  os_is_vgx_hyper             (void);
-RM_STATUS   NV_API_CALL  os_get_efi_screen_info      (NvU64 *, NvU32 *, NvU32 *);
+NV_STATUS   NV_API_CALL  os_inject_vgx_msi           (NvU16, NvU64, NvU32);
+NV_STATUS   NV_API_CALL  os_get_efi_screen_info      (NvU64 *, NvU32 *, NvU32 *);
 void        NV_API_CALL  os_bug_check                (NvU32, const char *);
-RM_STATUS   NV_API_CALL  os_lock_user_pages          (void *, NvU64, void **);
-RM_STATUS   NV_API_CALL  os_unlock_user_pages        (NvU64, void *);
-RM_STATUS   NV_API_CALL  os_match_mmap_offset        (void *, NvU64, NvU64 *);
+NV_STATUS   NV_API_CALL  os_lock_user_pages          (void *, NvU64, void **);
+NV_STATUS   NV_API_CALL  os_lookup_user_io_memory    (void *, NvU64, NvU64 **);
+NV_STATUS   NV_API_CALL  os_unlock_user_pages        (NvU64, void *);
+NV_STATUS   NV_API_CALL  os_match_mmap_offset        (void *, NvU64, NvU64 *);
 
 /*
  * ---------------------------------------------------------------------------
@@ -194,6 +196,8 @@ void NV_API_CALL  nv_prints(NvU32 debuglevel, const char *string);
 // #define NV_MEMORY_TYPE_AGP          1
 #define NV_MEMORY_TYPE_REGISTERS    2
 #define NV_MEMORY_TYPE_FRAMEBUFFER  3
+#define NV_MEMORY_TYPE_INSTANCE     4
+#define NV_MEMORY_TYPE_DEVICE_MMIO  5  /*  All kinds of MMIO referred by NVRM e.g. BARs and MCFG of device */
 
 #define NV_MEMORY_NONCONTIGUOUS     0
 #define NV_MEMORY_CONTIGUOUS        1
@@ -206,7 +210,6 @@ void NV_API_CALL  nv_prints(NvU32 debuglevel, const char *string);
 #define NV_MEMORY_WRITEBACK         5
 #define NV_MEMORY_DEFAULT           6
 #define NV_MEMORY_UNCACHED_WEAK     7
-#define NV_MEMORY_UNCACHED_DEVICE   8
 
 #define NV_PROTECT_READABLE   1
 #define NV_PROTECT_WRITEABLE  2
